==> kubernetes-client-4.7.2-sources.jar: io/fabric8/kubernetes/client/handlers/LeaseHandler.java <==

/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

                        

package io.fabric8.kubernetes.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.LeaseOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.coordination.v1beta1.Lease;
import io.fabric8.kubernetes.api.model.coordination.v1beta1.LeaseBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class LeaseHandler implements ResourceHandler<Lease, LeaseBuilder> {

  @Override
  public String getKind() {
    return Lease.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "coordination.k8s.io/v1beta1";
      }

  @Override
  public Lease create(OkHttpClient client, Config config, String namespace, Lease item) {
    return new LeaseOperationsImpl(client, config).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public Lease replace(OkHttpClient client, Config config, String namespace, Lease item) {
    return new LeaseOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public Lease reload(OkHttpClient client, Config config, String namespace, Lease item) {
    return new LeaseOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public LeaseBuilder edit(Lease item) {
    return new LeaseBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, Boolean cascading, Lease item) {
    return new LeaseOperationsImpl(client, config, namespace).withItem(item).cascading(cascading).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Lease item, Watcher<Lease> watcher) {
    return new LeaseOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Lease item, String resourceVersion, Watcher<Lease> watcher) {
    return new LeaseOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Lease waitUntilReady(OkHttpClient client, Config config, String namespace, Lease item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new LeaseOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public Lease waitUntilCondition(OkHttpClient client, Config config, String namespace, Lease item, Predicate<Lease> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new LeaseOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> kubernetes-client-4.9.1-sources.jar: io/fabric8/kubernetes/client/handlers/LeaseHandler.java <==

/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

                        

package io.fabric8.kubernetes.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.LeaseOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.coordination.v1.Lease;
import io.fabric8.kubernetes.api.model.coordination.v1.LeaseBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class LeaseHandler implements ResourceHandler<Lease, LeaseBuilder> {

  @Override
  public String getKind() {
    return Lease.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "coordination.k8s.io/v1";
      }

  @Override
  public Lease create(OkHttpClient client, Config config, String namespace, Lease item) {
    return new LeaseOperationsImpl(client, config).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public Lease replace(OkHttpClient client, Config config, String namespace, Lease item) {
    return new LeaseOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public Lease reload(OkHttpClient client, Config config, String namespace, Lease item) {
    return new LeaseOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public LeaseBuilder edit(Lease item) {
    return new LeaseBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, Boolean cascading, Lease item) {
    return new LeaseOperationsImpl(client, config, namespace).withItem(item).cascading(cascading).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Lease item, Watcher<Lease> watcher) {
    return new LeaseOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Lease item, String resourceVersion, Watcher<Lease> watcher) {
    return new LeaseOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Lease waitUntilReady(OkHttpClient client, Config config, String namespace, Lease item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new LeaseOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public Lease waitUntilCondition(OkHttpClient client, Config config, String namespace, Lease item, Predicate<Lease> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new LeaseOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
